from setuptools import setup, find_packages

setup(name='dobrepraktyki',
      version='0.1',
      author='Karol Polit',
      author_email='256438@student.pwr.edu.pl',
      packages=find_packages(),
      install_requires=["requests"]
      )
